@@ -284,22 +284,26 @@ class AttachRolePolicyRequest(AbstractModel):
 
     def __init__(self):
         """
-        :param PolicyId: Policy ID
+        :param PolicyId: Policy ID. Either `PolicyId` or `PolicyName` must be entered
         :type PolicyId: int
         :param AttachRoleId: Role ID, used to specify a role. Input either `AttachRoleId` or `AttachRoleName`
         :type AttachRoleId: str
         :param AttachRoleName: Role name, used to specify a role. Input either `AttachRoleId` or `AttachRoleName`
         :type AttachRoleName: str
+        :param PolicyName: Policy name. Either `PolicyId` or `PolicyName` must be entered
+        :type PolicyName: str
         """
         self.PolicyId = None
         self.AttachRoleId = None
         self.AttachRoleName = None
+        self.PolicyName = None
 
 
     def _deserialize(self, params):
         self.PolicyId = params.get("PolicyId")
         self.AttachRoleId = params.get("AttachRoleId")
         self.AttachRoleName = params.get("AttachRoleName")
+        self.PolicyName = params.get("PolicyName")
 
 
 class AttachRolePolicyResponse(AbstractModel):
@@ -904,22 +908,26 @@ class DetachRolePolicyRequest(AbstractModel):
 
     def __init__(self):
         """
-        :param PolicyId: Policy ID
+        :param PolicyId: Policy ID. Either `PolicyId` or `PolicyName` must be entered
         :type PolicyId: int
         :param DetachRoleId: Role ID, used to specify a role. Input either `AttachRoleId` or `AttachRoleName`
         :type DetachRoleId: str
         :param DetachRoleName: Role name, used to specify a role. Input either `AttachRoleId` or `AttachRoleName`
         :type DetachRoleName: str
+        :param PolicyName: Policy name. Either `PolicyId` or `PolicyName` must be entered
+        :type PolicyName: str
         """
         self.PolicyId = None
         self.DetachRoleId = None
         self.DetachRoleName = None
+        self.PolicyName = None
 
 
     def _deserialize(self, params):
         self.PolicyId = params.get("PolicyId")
         self.DetachRoleId = params.get("DetachRoleId")
         self.DetachRoleName = params.get("DetachRoleName")
+        self.PolicyName = params.get("PolicyName")
 
 
 class DetachRolePolicyResponse(AbstractModel):
@@ -1120,6 +1128,12 @@ Note: This field may return null, indicating that no valid value was found.
         :param PolicyDocument: Policy document
 Note: This field may return null, indicating that no valid value was found.
         :type PolicyDocument: str
+        :param PresetAlias: Remarks
+Note: this field may return null, indicating that no valid values can be obtained.
+        :type PresetAlias: str
+        :param IsServiceLinkedRolePolicy: Whether it is a service-linked policy
+Note: this field may return null, indicating that no valid values can be obtained.
+        :type IsServiceLinkedRolePolicy: int
         :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
         :type RequestId: str
         """
@@ -1129,6 +1143,8 @@ Note: This field may return null, indicating that no valid value was found.
         self.AddTime = None
         self.UpdateTime = None
         self.PolicyDocument = None
+        self.PresetAlias = None
+        self.IsServiceLinkedRolePolicy = None
         self.RequestId = None
 
 
@@ -1139,6 +1155,8 @@ Note: This field may return null, indicating that no valid value was found.
         self.AddTime = params.get("AddTime")
         self.UpdateTime = params.get("UpdateTime")
         self.PolicyDocument = params.get("PolicyDocument")
+        self.PresetAlias = params.get("PresetAlias")
+        self.IsServiceLinkedRolePolicy = params.get("IsServiceLinkedRolePolicy")
         self.RequestId = params.get("RequestId")
 
 
@@ -1586,6 +1604,57 @@ class ListAttachedUserPoliciesResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class ListCollaboratorsRequest(AbstractModel):
+    """ListCollaborators request structure.
+
+    """
+
+    def __init__(self):
+        """
+        :param Limit: Number of entries per page. Default value: 20
+        :type Limit: int
+        :param Offset: Pagination start value. Default value: 0
+        :type Offset: int
+        """
+        self.Limit = None
+        self.Offset = None
+
+
+    def _deserialize(self, params):
+        self.Limit = params.get("Limit")
+        self.Offset = params.get("Offset")
+
+
+class ListCollaboratorsResponse(AbstractModel):
+    """ListCollaborators response structure.
+
+    """
+
+    def __init__(self):
+        """
+        :param TotalNum: Total number
+        :type TotalNum: int
+        :param Data: Collaborator information
+        :type Data: list of SubAccountInfo
+        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
+        :type RequestId: str
+        """
+        self.TotalNum = None
+        self.Data = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.TotalNum = params.get("TotalNum")
+        if params.get("Data") is not None:
+            self.Data = []
+            for item in params.get("Data"):
+                obj = SubAccountInfo()
+                obj._deserialize(item)
+                self.Data.append(obj)
+        self.RequestId = params.get("RequestId")
+
+
 class ListEntitiesForPolicyRequest(AbstractModel):
     """ListEntitiesForPolicy request structure.
 
@@ -1660,16 +1729,20 @@ class ListGroupsForUserRequest(AbstractModel):
         :type Rp: int
         :param Page: Page number; default is 1
         :type Page: int
+        :param SubUin: Sub-account UIN
+        :type SubUin: int
         """
         self.Uid = None
         self.Rp = None
         self.Page = None
+        self.SubUin = None
 
 
     def _deserialize(self, params):
         self.Uid = params.get("Uid")
         self.Rp = params.get("Rp")
         self.Page = params.get("Page")
+        self.SubUin = params.get("SubUin")
 
 
 class ListGroupsForUserResponse(AbstractModel):
@@ -1953,72 +2026,6 @@ class ListUsersResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
-class LoginActionFlag(AbstractModel):
-    """Login and sensitive operation flag
-
-    """
-
-    def __init__(self):
-        """
-        :param Phone: Mobile phone
-        :type Phone: int
-        :param Token: Hard token
-        :type Token: int
-        :param Stoken: Soft token
-        :type Stoken: int
-        :param Wechat: WeChat
-        :type Wechat: int
-        :param Custom: Custom
-        :type Custom: int
-        """
-        self.Phone = None
-        self.Token = None
-        self.Stoken = None
-        self.Wechat = None
-        self.Custom = None
-
-
-    def _deserialize(self, params):
-        self.Phone = params.get("Phone")
-        self.Token = params.get("Token")
-        self.Stoken = params.get("Stoken")
-        self.Wechat = params.get("Wechat")
-        self.Custom = params.get("Custom")
-
-
-class OffsiteFlag(AbstractModel):
-    """Remote login settings
-
-    """
-
-    def __init__(self):
-        """
-        :param VerifyFlag: Verification identifier
-        :type VerifyFlag: int
-        :param NotifyPhone: Phone notification
-        :type NotifyPhone: int
-        :param NotifyEmail: Email notification
-        :type NotifyEmail: int
-        :param NotifyWechat: WeChat notification
-        :type NotifyWechat: int
-        :param Tips: Alert
-        :type Tips: int
-        """
-        self.VerifyFlag = None
-        self.NotifyPhone = None
-        self.NotifyEmail = None
-        self.NotifyWechat = None
-        self.Tips = None
-
-
-    def _deserialize(self, params):
-        self.VerifyFlag = params.get("VerifyFlag")
-        self.NotifyPhone = params.get("NotifyPhone")
-        self.NotifyEmail = params.get("NotifyEmail")
-        self.NotifyWechat = params.get("NotifyWechat")
-        self.Tips = params.get("Tips")
-
-
 class RemoveUserFromGroupRequest(AbstractModel):
     """RemoveUserFromGroup request structure.
 
@@ -2079,13 +2086,14 @@ class RoleInfo(AbstractModel):
         :type UpdateTime: str
         :param ConsoleLogin: If login is allowed for the role
         :type ConsoleLogin: int
-        :param RoleType: User role. Valid values: user, system
+        :param RoleType: User role. Valid values: `user`, `system`, `service_linked`
 Note: this field may return null, indicating that no valid values can be obtained.
         :type RoleType: str
         :param SessionDuration: Valid period
 Note: this field may return null, indicating that no valid values can be obtained.
         :type SessionDuration: int
-        :param DeletionTaskId: 
+        :param DeletionTaskId: Task identifier for deleting a service-linked role 
+Note: this field may return null, indicating that no valid values can be obtained.
         :type DeletionTaskId: str
         """
         self.RoleId = None
@@ -2142,62 +2150,6 @@ class SAMLProviderInfo(AbstractModel):
         self.ModifyTime = params.get("ModifyTime")
 
 
-class SetFlagRequest(AbstractModel):
-    """SetFlag request structure.
-
-    """
-
-    def __init__(self):
-        """
-        :param OpUin: Set user UIN
-        :type OpUin: int
-        :param LoginFlag: Login settings
-        :type LoginFlag: :class:`tencentcloud.cam.v20190116.models.LoginActionFlag`
-        :param ActionFlag: Sensitive operation settings
-        :type ActionFlag: :class:`tencentcloud.cam.v20190116.models.LoginActionFlag`
-        :param OffsiteFlag: Remote login settings
-        :type OffsiteFlag: :class:`tencentcloud.cam.v20190116.models.OffsiteFlag`
-        :param NeedResetMfa: If MFA requires top-up
-        :type NeedResetMfa: int
-        """
-        self.OpUin = None
-        self.LoginFlag = None
-        self.ActionFlag = None
-        self.OffsiteFlag = None
-        self.NeedResetMfa = None
-
-
-    def _deserialize(self, params):
-        self.OpUin = params.get("OpUin")
-        if params.get("LoginFlag") is not None:
-            self.LoginFlag = LoginActionFlag()
-            self.LoginFlag._deserialize(params.get("LoginFlag"))
-        if params.get("ActionFlag") is not None:
-            self.ActionFlag = LoginActionFlag()
-            self.ActionFlag._deserialize(params.get("ActionFlag"))
-        if params.get("OffsiteFlag") is not None:
-            self.OffsiteFlag = OffsiteFlag()
-            self.OffsiteFlag._deserialize(params.get("OffsiteFlag"))
-        self.NeedResetMfa = params.get("NeedResetMfa")
-
-
-class SetFlagResponse(AbstractModel):
-    """SetFlag response structure.
-
-    """
-
-    def __init__(self):
-        """
-        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
-        :type RequestId: str
-        """
-        self.RequestId = None
-
-
-    def _deserialize(self, params):
-        self.RequestId = params.get("RequestId")
-
-
 class StrategyInfo(AbstractModel):
     """Policy information
 
@@ -2232,7 +2184,8 @@ Note: this field may return null, indicating that no valid values can be obtaine
         :param DeactivedDetail: List of deprecated products
 Note: this field may return null, indicating that no valid values can be obtained.
         :type DeactivedDetail: list of str
-        :param IsServiceLinkedPolicy: 
+        :param IsServiceLinkedPolicy: The deletion task identifier used to check the deletion status of the service-linked role
+Note: this field may return null, indicating that no valid values can be obtained.
         :type IsServiceLinkedPolicy: int
         """
         self.PolicyId = None
@@ -2393,37 +2346,33 @@ class UpdateGroupResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
-class UpdatePolicyRequest(AbstractModel):
-    """UpdatePolicy request structure.
+class UpdateRoleConsoleLoginRequest(AbstractModel):
+    """UpdateRoleConsoleLogin request structure.
 
     """
 
     def __init__(self):
         """
-        :param PolicyId: Policy ID
-        :type PolicyId: int
-        :param PolicyName: Policy name
-        :type PolicyName: str
-        :param Description: Policy description
-        :type Description: str
-        :param PolicyDocument: Policy document, such as `{"version":"2.0","statement":[{"action":"name/sts:AssumeRole","effect":"allow","principal":{"service":["cloudaudit.cloud.tencent.com","cls.cloud.tencent.com"]}}]}`, where `principal` is used to specify the resources that the role is authorized to access. For more information on this parameter, please see the `RoleInfo` output parameter of the [GetRole](https://cloud.tencent.com/document/product/598/36221) API
-        :type PolicyDocument: str
+        :param ConsoleLogin: Whether login is allowed. 1: yes, 0: no
+        :type ConsoleLogin: int
+        :param RoleId: Role ID
+        :type RoleId: int
+        :param RoleName: Role name
+        :type RoleName: str
         """
-        self.PolicyId = None
-        self.PolicyName = None
-        self.Description = None
-        self.PolicyDocument = None
+        self.ConsoleLogin = None
+        self.RoleId = None
+        self.RoleName = None
 
 
     def _deserialize(self, params):
-        self.PolicyId = params.get("PolicyId")
-        self.PolicyName = params.get("PolicyName")
-        self.Description = params.get("Description")
-        self.PolicyDocument = params.get("PolicyDocument")
+        self.ConsoleLogin = params.get("ConsoleLogin")
+        self.RoleId = params.get("RoleId")
+        self.RoleName = params.get("RoleName")
 
 
-class UpdatePolicyResponse(AbstractModel):
-    """UpdatePolicy response structure.
+class UpdateRoleConsoleLoginResponse(AbstractModel):
+    """UpdateRoleConsoleLogin response structure.
 
     """
 
